function [goalTypes, blkCondSldvOpts, objectiveTypes] = getSupportedBlockConditions
% blkCondSldvOpts: list of SLDV options for block condition checks
% goalTypes: Corresponding goal types
% objectiveTypes: Corresponding objective types
%
% PS: Order of items in these lists should match each other

% Copyright 2020 The MathWorks, Inc.

    blkCondSldvOpts = { 'HISL_0002', ...
                        'HISL_0003', ...
                        'HISL_0004', ...
                        'HISL_0005', ...
                        'HISL_0028', ...
                      };

    goalTypes = { 'AVT_GOAL_HISL_0002', ...
                  'AVT_GOAL_HISL_0003', ...
                  'AVT_GOAL_HISL_0004', ...
                  'AVT_GOAL_HISL_0005', ...
                  'AVT_GOAL_HISL_0028', ...
                };

    objectiveTypes = { 'Hisl_0002', ...
                       'Hisl_0003', ...
                       'Hisl_0004', ...
                       'Hisl_0005', ...
                       'Hisl_0028', ...
                     };
end
